package Kakuro;

import choco.integer.IntDomainVar;
import choco.AbstractProblem;

/**
 * Each cell is involved in two sequences of variables
 * constrained by a sum+alldiff
 */
public class Cell {

	/**
	 * the coordinate of the cell
	 */
	protected int i,j;

	/**
	 * the two sequences involving this cell
	 */
	protected Sequence s1, s2;

	/**
	 * The choco variable representing the cell in the KakuroProblem class
	 */
	protected IntDomainVar var;


	public Cell(int i, int j) {
		this.i = i;
		this.j = j;
	}

	public void setHorizontalSeq(Sequence seq) {
		s1 = seq;
	}

	public void setVerticalSeq(Sequence seq) {
		s2 = seq;
	}

	/**
	 * return a proper variable with initial domain reductions
	 *
	 **/
	public IntDomainVar createVariable(AbstractProblem pb) {
		int lb, ub;
		lb = s1.spb.getLowerBound();
		ub = s1.spb.getUpperBound();
		lb = Math.max(s2.spb.getLowerBound(), lb);
		ub = Math.min(s2.spb.getUpperBound(), ub);
		var = pb.makeEnumIntVar("["+ i + "][" + j + "]", lb, ub);
		return var;
	}

	public String toString(){
		return var.getVal()+"";
	}
}
